@@ -3,7 +3,7 @@ from openvino.runtime import Core
 
 
 # 基于OpenVino推理引擎封装的通用OpenVino推理器
-class OpenvinoPredict(object):
+class Model(object):
     def __init__(self, model, device='AUTO'):
         self.core = Core()
         self.model = self.core.read_model(model=model)
@@ -11,11 +11,11 @@ class OpenvinoPredict(object):
         self.input_keys = self.compiled_model.inputs
         self.output_keys = self.compiled_model.outputs
 
-    def predict(self, inputs: list) -> list:
-        results = self.compiled_model(inputs)
+    def predict(self, input_list: list) -> list:
+        results = self.compiled_model(input_list)
 
-        outputs = []
+        output_list = []
         for output_key in self.output_keys:
-            outputs.append(results[output_key])
+            output_list.append(results[output_key])
 
-        return outputs
+        return output_list
